@@ -2,13 +2,15 @@ import numpy as np
 from pathlib import Path
 from mylogging import user_warning
 
+from .models_functions.models_functions import one_step_looper
 
-def train(sequentions, layers='default', predicts=7, epochs=200, load_trained_model=0, update_trained_model=1, save_model=1,
+
+def train(data, layers='default', epochs=200, load_trained_model=0, update_trained_model=1, save_model=1,
           saved_model_path_string='stored_models', optimizer='adam', loss='mse', verbose=0, used_metrics='accuracy', timedistributed=0, batch_size=64):
-    """Tensorflow model. Neural nets - LSTM or MLP (just dense layers). Layers are customizable with arguments.
+    """Tensorflow model. Neural nets - LSTM or MLP (dense layers). Layers are customizable with arguments.
 
     Args:
-        sequentions (tuple(np.ndarray, np.ndarray, np.ndarray)) - Tuple (X, y, x_input) of input train vectors X, train outputs y, and input for prediction x_input
+        data ((np.ndarray, np.ndarray)) - Tuple (X, y) of input train vectors X and train outputs y
         layers (tuple) - Tuple of tuples of layer name (e.g. 'lstm') and layer params dict (e.g. {'units': 7, 'activation': 'relu'}). Check default layres tuple here or config example.
         predicts (int, optional): Number of predicted values. Defaults to 7.
         epochs (int, optional): Number of epochs to evaluate. Defaults to 100.
@@ -38,8 +40,8 @@ def train(sequentions, layers='default', predicts=7, epochs=200, load_trained_mo
                   ('dropout', {'rate': 0.1}),
                   ('lstm', {'units': 7, 'activation': 'relu'}))
 
-    X = sequentions[0]
-    y = sequentions[1]
+    X = data[0]
+    y = data[1]
     X_ndim = X.ndim
 
     models = {'dense': tf.keras.layers.Dense, 'lstm': tf.keras.layers.LSTM, 'mlp': tf.keras.layers.Dense, 'gru': tf.keras.layers.GRU, 'conv2d': tf.keras.layers.Conv2D, 'rnn': tf.keras.layers.SimpleRNN, 'convlstm2d': tf.keras.layers.ConvLSTM2D, 'dropout': tf.keras.layers.Dropout, 'batchnormalization': tf.keras.layers.BatchNormalization}
@@ -48,6 +50,8 @@ def train(sequentions, layers='default', predicts=7, epochs=200, load_trained_mo
         metrics = [tf.keras.metrics.Accuracy()]
     elif used_metrics == 'mape':
         metrics = [tf.keras.metrics.MeanAbsolutePercentageError()]
+    else:
+        raise ValueError("metrics has to be one from ['accuracy', 'mape']")
 
     if saved_model_path_string == 'stored_models':
         saved_model_path_string = str(Path(__file__).resolve().parent / 'stored_models' / 'tensorflow.h5')
@@ -61,7 +65,7 @@ def train(sequentions, layers='default', predicts=7, epochs=200, load_trained_mo
             raise NameError("Model is not saved, first saveit = 1 in config")
 
         if update_trained_model:
-            model.fit(X, y, epochs=epochs, batch_size=64, verbose=verbose)
+            model.fit(X, y, epochs=epochs, batch_size=batch_size, verbose=verbose)
 
     else:
         if layers[0][0] == 'lstm':
@@ -85,7 +89,7 @@ def train(sequentions, layers='default', predicts=7, epochs=200, load_trained_mo
             model.add(tf.keras.layers.Dense(y.shape[1]))
 
         model.compile(optimizer=optimizer, loss=loss, metrics=metrics)
-        model.fit(X, y, epochs=epochs, batch_size=64, verbose=verbose)
+        model.fit(X, y, epochs=epochs, batch_size=batch_size, verbose=verbose)
 
     if save_model == 1:
         model.save(saved_model_path_string)
@@ -114,18 +118,7 @@ def predict(x_input, model, predicts=7):
         x_input = x_input.reshape(1, x_input.shape[1], x_input.shape[0])
     predictions = []
 
-    ### One step univariate prediction
-    if model.y_shape_1 == 1:
-        for i in range(predicts):
-            yhat = model.predict(x_input)
-            x_input = np.insert(x_input, x_input.shape[1], yhat[0][0], axis=1)
-            x_input = np.delete(x_input, 0, axis=1)
-            predictions.append(yhat[0][0])
-        predictions = np.array(predictions)
-
-    ### Batch multivariate prediction
-    else:
-        predictions = model.predict(x_input)[0]
+    predictions = model.predict(x_input)[0]
 
     return predictions
 
